==> ah-react-ui-1.0.55.tgz: package/lib/esm/form/fields.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { createElement as _createElement } from "react";
import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { Input, InputNumber, AutoComplete, Select } from "antd";
import styled from "styled-components";
export var InputField = function (props) {
    var _a;
    return (_jsxs(FieldWithLabel, { children: [_jsxs("label", { children: [props.label, props.isRequired] }), _createElement(Input, __assign({}, props, { value: props.field.value, onChange: function (e) { return props.field.onChange(e.target.value); }, key: props.label })), _jsx(ErrorValidation, { children: props.field.errorText((_a = {},
                    _a[props.field.name] = props.errorText,
                    _a)) })] }));
};
export var InputNumberField = function (props) {
    var _a;
    return (_jsxs(FieldWithLabel, { children: [_jsx("label", { children: props.label }), _createElement(InputNumber, __assign({}, props, { value: props.field.value, onChange: function (e) { return props.field.onChange(e); }, key: props.label })), _jsx(ErrorValidation, { children: props.field.errorText((_a = {},
                    _a[props.field.name] = props.errorText,
                    _a)) })] }));
};
export var AutoCompleteField = function (props) {
    var _a;
    return (_jsxs(FieldWithLabel, { children: [_jsxs("label", { children: [props.label, props.isRequired] }), _createElement(AutoComplete, __assign({ style: { width: "100%" } }, props, { value: props.field.value, onChange: function (e) { return props.field.onChange(e); }, key: props.label })), _jsx(ErrorValidation, { children: props.field.errorText((_a = {},
                    _a[props.field.name] = props.errorText,
                    _a)) })] }));
};
export var SelectField = function (props) {
    var _a;
    return (_jsxs(FieldWithLabel, { children: [_jsx("label", { children: props.label }), _jsx(Select, __assign({}, props, { showSearch: true, value: props.field.value, onChange: function (option) { return props.field.onChange(option); } }, { children: props.children })), _jsx(ErrorValidation, { children: props.field.errorText((_a = {},
                    _a[props.field.name] = props.errorText,
                    _a)) })] }));
};
SelectField.Item = function (props) {
    return (_createElement(Select.Option, __assign({}, props, { value: props.value, key: props.value }), props.children ? props.children : props.value));
};
export var InlineFieldGroup = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  display: flex;\n  gap: 20px;\n"], ["\n  display: flex;\n  gap: 20px;\n"])));
var ErrorValidation = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  color: red;\n"], ["\n  color: red;\n"])));
var FieldWithLabel = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  width: 100%;\n  display: flex;\n  flex-direction: column;\n  gap: 10px;\n"], ["\n  width: 100%;\n  display: flex;\n  flex-direction: column;\n  gap: 10px;\n"])));
var templateObject_1, templateObject_2, templateObject_3;

==> ah-react-ui-1.0.60.tgz: package/lib/esm/form/fields.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { createElement as _createElement } from "react";
import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { Input, InputNumber, AutoComplete, Select, DatePicker as DatePickerDefault } from "antd";
import styled from "styled-components";
import moment from "moment/moment";
export var InputField = function (props) {
    var _a;
    return (_jsxs(FieldWithLabel, { children: [_jsxs("label", { children: [props.label, props.isRequired] }), _createElement(Input, __assign({}, props, { value: props.field.value, onChange: function (e) { return props.field.onChange(e.target.value); }, key: props.label })), _jsx(ErrorValidation, { children: props.field.errorText((_a = {},
                    _a[props.field.name] = props.errorText,
                    _a)) })] }));
};
export var InputNumberField = function (props) {
    var _a;
    return (_jsxs(FieldWithLabel, { children: [_jsx("label", { children: props.label }), _createElement(InputNumber, __assign({}, props, { value: props.field.value, onChange: function (e) { return props.field.onChange(e); }, key: props.label })), _jsx(ErrorValidation, { children: props.field.errorText((_a = {},
                    _a[props.field.name] = props.errorText,
                    _a)) })] }));
};
export var AutoCompleteField = function (props) {
    var _a;
    return (_jsxs(FieldWithLabel, { children: [_jsxs("label", { children: [props.label, props.isRequired] }), _createElement(AutoComplete, __assign({ style: { width: "100%" } }, props, { value: props.field.value, onChange: function (e) { return props.field.onChange(e); }, key: props.label })), _jsx(ErrorValidation, { children: props.field.errorText((_a = {},
                    _a[props.field.name] = props.errorText,
                    _a)) })] }));
};
export var SelectField = function (props) {
    var _a;
    return (_jsxs(FieldWithLabel, { children: [_jsx("label", { children: props.label }), _jsx(Select, __assign({}, props, { showSearch: true, value: props.field.value, onChange: function (option) { return props.field.onChange(option); } }, { children: props.children })), _jsx(ErrorValidation, { children: props.field.errorText((_a = {},
                    _a[props.field.name] = props.errorText,
                    _a)) })] }));
};
SelectField.Item = function (props) {
    return (_createElement(Select.Option, __assign({}, props, { value: props.value, key: props.value }), props.children ? props.children : props.value));
};
export var DatePicker = function (props) {
    props.field.value = props.field.value === null ? undefined : props.field.value;
    return _jsxs(FieldWithLabel, { children: [_jsx("label", { children: props.label }), _jsx(DatePickerDefault, __assign({}, props, { value: moment(props.field.value), style: { width: "100%" }, onChange: function (date) { return props.field.onChange(date); } }))] });
};
export var InlineFieldGroup = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  display: flex;\n  gap: 20px;\n"], ["\n  display: flex;\n  gap: 20px;\n"])));
var ErrorValidation = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  color: red;\n"], ["\n  color: red;\n"])));
var FieldWithLabel = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  width: 100%;\n  display: flex;\n  flex-direction: column;\n  gap: 10px;\n"], ["\n  width: 100%;\n  display: flex;\n  flex-direction: column;\n  gap: 10px;\n"])));
var templateObject_1, templateObject_2, templateObject_3;
